summaryrefslogtreecommitdiff
path: root/qtart.c
diff options
context:
space:
mode:
Diffstat (limited to 'qtart.c')
-rw-r--r--qtart.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/qtart.c b/qtart.c
index 1b17c1c..c670b46 100644
--- a/qtart.c
+++ b/qtart.c
@@ -457,12 +457,14 @@ int main(int argc, char **argv)
if (!empty_run) {
js_std_add_helpers(ctx, argc - optind, argv + optind);
/* make 'std' and 'os' visible to non module code */
if (load_std) {
const char *str = "import * as std from 'std';\n"
"import * as os from 'os';\n"
+ "import * as tart from 'tart';\n"
"globalThis.std = std;\n"
- "globalThis.os = os;\n";
+ "globalThis.os = os;\n"
+ "globalThis.tart = tart;\n";
eval_buf(ctx, str, strlen(str), "<input>", JS_EVAL_TYPE_MODULE);
}
@@ -457,12 +457,14 @@ int main(int argc, char **argv)
if (!empty_run) {
js_std_add_helpers(ctx, argc - optind, argv + optind);
- /* make 'std' and 'os' visible to non module code */
+ /* make 'std', 'os' and 'tart' visible to non module code */
if (load_std) {
const char *str = "import * as std from 'std';\n"